@@ -16,19 +16,20 @@ Including another URLconf
 from django.contrib import admin
 from django.urls import path, include
 from django.shortcuts import redirect
-from snort.views import get_rule, get_rule_keys, build_rule_keyword_to_rule, build_rule_rule_to_keywords, favico
+from snort.views import get_rule, get_rule_keys, build_rule_keyword_to_rule, build_rule_rule_to_keywords, favico,get_current_user_name
 from django.conf import settings
 from django.conf.urls.static import static
 
 admin.site.site_header = 'snort web master'
-
+app_name = "snort_web_master"
 urlpatterns = [
     path("favicon.ico", favico),
-    path("get_rule_update/<int:rule_id>/", get_rule),
-    path("get_rule_keywords/<int:rule_id>/", get_rule_keys),
-    path('advanced_filters/', include("advanced_filters.urls")),
-    path("build_rule/keyword_to_rule", build_rule_keyword_to_rule),
-    path("build_rule/rule_to_keywords", build_rule_rule_to_keywords),
-    path('admin/', admin.site.urls),
-    path('', lambda request: redirect('admin/', permanent=True)),
+    path("get_rule_update/<int:rule_id>/", get_rule, name="get_rule_update"),
+    path("get_rule_keywords/<int:rule_id>/", get_rule_keys,name="get_rule_keywords"),
+    path('advanced_filters/', include("advanced_filters.urls"), name="advance_filter"),
+    path("build_rule/keyword_to_rule", build_rule_keyword_to_rule,name="build_rule"),
+    path("build_rule/rule_to_keywords", build_rule_rule_to_keywords,name="build_keyword"),
+    path("current_user_name", get_current_user_name, name="get_current_user_name"),
+    path('admin/', admin.site.urls, name="admin_main"),
+    path('',  admin.site.urls, name="admin_main"),
 ]+ static("static/", document_root=settings.STATIC_ROOT) + static("/", document_root=settings.BASE_DIR)
